var infoButton = null;
var doneButton = null;
var alarm = {
	'sound': 'none',
	'voice': 'none',
	'growl': false
};

/**
 * Add all event listeners when the window is loaded.
 */
$(window).load(function() {	
	timer = new Timer();
	front = new Front();
	back = new Back();
	updater = new Updater();
	infoButton = new AppleInfoButton($('#infoButton').get(0),
		$('#front').get(0), 'white', 'white', showBack);
	doneButton = new AppleGlassButton($('#doneButton').get(0),
		getLocalizedString('Done'), showFront);
	
	if (window.widget) {
		widget.onremove = remove;
		widget.onhide = hide;
		widget.onshow = show;
	}
	
	loadLocalizedStrings();
	loadPreferences();
});

/**
 * Load all localized strings.
 */
function loadLocalizedStrings() {
	// Front side
	$('#timerTarget').text(getLocalizedString('Tea'));
	$('#readyIn').text(getLocalizedString('ready in'));
	$('#readyInInput > option:nth-child(1)').text(
			getLocalizedString('ready in'));
	$('#readyInInput > option:nth-child(2)').text(
			getLocalizedString('in'));
	$('#hoursLabel').text(getLocalizedString('hrs.'));
	$('#minutesLabel').text(getLocalizedString('mins.'));
	$('#secondsLabel').text(getLocalizedString('secs.'));
	
	// Back side
	$('#homeLink > a').text(getLocalizedString('Tea Timer website'));
	$('#prefBgColorLabel').text(getLocalizedString('Background color') + ':');
	$('#backgroundColor > option[value=default]')
			.text(getLocalizedString('Default'));
	$('#backgroundColor > option[value=cayenne]')
			.text(getLocalizedString('Cayenne'));
	$('#backgroundColor > option[value=graphite]')
			.text(getLocalizedString('Graphite'));
	$('#backgroundColor > option[value=lime]')
			.text(getLocalizedString('Lime'));
	$('#backgroundColor > option[value=ocean]')
			.text(getLocalizedString('Ocean'));
	$('#backgroundColor > option[value=orange]')
			.text(getLocalizedString('Orange'));
	$('#backgroundColor > option[value=purple]')
			.text(getLocalizedString('Purple'));
	$('#backgroundColor > option[value=silver]')
			.text(getLocalizedString('Silver'));
	$('#alarmVoiceLabel').text(getLocalizedString('Voice') + ':');
	$('#alarmVoice > option:first').text(getLocalizedString('Off'));
	$('#alarmSoundLabel').text(getLocalizedString('Sound') + ':');
	$('#alarmSound > option:first').text(getLocalizedString('Off'));
	$('#alarmGrowlLabel').text(getLocalizedString('Use Growl'));
	
	
	// Update panel
	$('#updateLabel').text(getLocalizedString('Update available'));
	$('#clientVersionLabel').text(getLocalizedString('Your version') + ':');
	$('#availableVersionLabel').text(getLocalizedString('New version') + ':');	
}

/**
 * Load and restore the user preferences.
 */
function loadPreferences() {
	if (window.widget) {
		var buf = widget.preferenceForKey('background');
		if (buf && buf.length > 0) {
			$('#front').css('background', 'url(Images/Front_' + buf
				+ '.png) no-repeat');
			$('#backgroundColor').attr('value', buf);
		}
		buf = widget.preferenceForKey('timerTarget');
		if (buf && buf.length > 0) {
			$('#timerTarget').text(buf);
		}
		buf = widget.preferenceForKey('readyIn');
		if (buf && buf.length > 0) {
			$('#readyIn').text(buf);
		}
		buf = widget.preferenceForKey('alarm.sound');
		if (buf && buf.length > 0) {
			alarm.sound = buf;
			$('#alarmSound').attr('value', buf);
		}
		buf = widget.preferenceForKey('alarm.voice');
		if (buf && buf.length > 0) {
			alarm.voice = buf;
			$('#alarmVoice').attr('value', buf);
		}
		buf = widget.preferenceForKey('alarm.growl');
		if (buf && buf.length > 0) {
			alarm.growl = buf;
			if (buf == 'on')
				$('#alarmGrowl').attr('checked', 'checked');
		}
	}
}

/**
 * Get a localized string for a key.
 *
 * @param key: Search string for that key.
 * @return: The localized string if found, else the key.
 */
function getLocalizedString(key)
{
	try {
		var ret = localizedStrings[key];
		if (ret === undefined)
			ret = key;
		return ret;
	} catch (ex) {}
	return key;
}

/**
 * Called when the widget has been removed from the Dashboard.
 */
function remove() {
	// Stop any timers to prevent CPU usage
	// Remove any preferences as needed
	// widget.setPreferenceForKey(null, dashcode.createInstancePreferenceKey("your-key"));
}

/**
 * Called when the widget has been hidden.
 */
function hide() {
	// Don't stop the timer or you'll forget your tea!
}

/**
 * Called when the widget has been shown.
 */
function show() {
	updater.check();
}

/**
 * Called when the info button is clicked to show the back of the widget.
 *
 * @param event: onClick event from the info button
 */
function showBack(event) {
	if (window.widget) {
		window.resizeTo(320, 150);
		widget.prepareForTransition("ToBack");
	}

	$('#front').css('display', 'none');
	$('#back').css('display', 'block');

	if (window.widget) {
		setTimeout('widget.performTransition();', 0);
	}
}

/**
 * Called when the done button is clicked from the back of the widget.
 *
 * @param event: onClick event from the done button
 */
function showFront(event) {
	if (window.widget) {
		widget.prepareForTransition("ToFront");
		window.resizeTo(320, 120);
	}

	$('#front').css('display', 'block');
	$('#back').css('display', 'none');

	if (window.widget) {
		setTimeout('widget.performTransition();', 0);
	}
}
